# SkiLift.py

from gamegrid import *
from EmptyPlatter import EmptyPlatter

class SkiLift(Actor):
    liftSpeed = 0.6
    liftDirection = [.95, -3]
    liftDirectionTop = [3.3, -0.31]
    platterNumber = 20
    platterPeriod = 35
    liftStart = [44, 575]
    liftTopBorder = 1001
    queueStartingPoint = Location(50, 573)
    queueWaitingDistance = 30
    queue = []

    def __init__(self, skiResort):
        Actor.__init__(self, "sprites/skilift.png")
        self.skiResort = skiResort

    def act(self):
    # a platter comes every platterPeriod
        if self.getNbCycles() % SkiLift.platterPeriod == 0:
            if len(SkiLift.queue) == 0:
                # create empty platter if nobody in queue
                self.skiResort.addActor(EmptyPlatter(self), Location(-50, -50))
                self.skiResort.setPaintOrder(SkiLift, EmptyPlatter) # platter behind lift
            else:
                # take first skier in queue and put him on lift
                skier = SkiLift.queue.pop(0)
                skier.setState("onLift")
                if skier.isSlow():
                    skier.show(4)
                else:
                    skier.show(5)
                # Set at start of lift
                skier.setPosition(SkiLift.liftStart[0], SkiLift.liftStart[1])
                # Advance the queue
                for i in range(len(SkiLift.queue)): 
                    oldX = SkiLift.queue[i].getX()
                    SkiLift.queue[i].setX(oldX - SkiLift.queueWaitingDistance)

    def put(self, skier):
        # Insert the skier in queue
        if len (SkiLift.queue) > 0:
            posXOfLastSkierInQueue = SkiLift.queue[-1].getX()
            loc = Location(posXOfLastSkierInQueue + SkiLift.queueWaitingDistance, SkiLift.queueStartingPoint.y)
            skier.setLocation(loc)
        else:
            # Empty queue -> go to first position
            skier.setLocation(SkiLift.queueStartingPoint)
        
        SkiLift.queue.append(skier)
        # set sprite to "wait"-sprite
        if skier.isSlow():
            skier.show(2)
        else:
            skier.show(3)
        skier.setDirection(0)
  
    def get(self):
        #  returns first skier in line or None if the queue is empty
        if len(SkiLift.queue) == 0:
            return None

        skier = selfqueue.pop(0)
        # set sprite to "onLift"-sprite
        if skier.isSlow():
            skier.show(4)
        else:
            skier.show(5)
        return skier

    def getSlowSkiersInQueue(self):
        slowSkiers = 0
        for skier in SkiLift.queue:
            if skier.isSlow():
                slowSkiers += 1
        return slowSkiers

    def purgeQueue(self):
        SkiLift.queue = []

    def getQueueSize(self):
        return len(SkiLift.queue)
