# SkiResort.py

from gamegrid import *
from random import shuffle
from SkiLift import SkiLift
from Skier import Skier
from EmptyPlatter import EmptyPlatter
from InfoBoard import InfoBoard

class SkiResort(GameGrid):
    def __init__(self):
        GameGrid.__init__(self, 800, 600, 1, None, "sprites/skiresort.png", True)
        self.nbSkiers = 24
        self.skiLift = SkiLift(self)
        self.infoBoard = InfoBoard(self, self.skiLift, self.nbSkiers)
        self.skiers = [0] * self.nbSkiers
        self.setSimulationPeriod(40)
        self.reset()
        self.show()
        self.setTitle("Ski Resort Simulation With Slow And Fast Skiers")
        self.addStatusBar(30)
        self.setStatusText("Fast skiers (red) are 3 times as fast as slow skiers (blue)",  Font("SansSerif", Font.BOLD, 15), Color.black)    
        self.infoBoard.start()

    def reset(self):
        self.removeAllActors()
        # the first half of the skiers are slow:
        for i in range(self.nbSkiers // 2):
            self.skiers[i] = Skier(self, self.infoBoard, True)
        # the second half of the skiers are fast:
        for i in range(self.nbSkiers // 2, self.nbSkiers):
            self.skiers[i] = Skier(self, self.infoBoard, False)
        self.addActor(self.skiLift, Location(135, 297))
        self.skiLift.purgeQueue()
        # Mix fast and slow skiers
        shuffle(self.skiers)
        for i in range(len(self.skiers)):
            self.addActor(self.skiers[i], Location(-50, -50)) # out of view
            self.skiers[i].setState("inQueue")
            self.skiLift.put(self.skiers[i])
        self.setPaintOrder(SkiLift, Skier, EmptyPlatter)

SkiResort()
