# Skier.py

from gamegrid import *
import random
from SkiLift import SkiLift

class Skier(Actor):
    state = "onTrack"  # onList, inQueue
    lastId = 0

    def __init__(self, skiResort, infoBoard, slow):
        Actor.__init__(self, True, "sprites/skier.png", 6) 
        self.skiResort = skiResort
        self.infoBoard = infoBoard
        self.slow = slow
        self.trackCountReported = False

    def reset(self):
        self.listTopBorder = 1001
        self.id = Skier.lastId + 1
        Skier.lastId = self.id
        
    def getLiftSpeed(self):
        return Skier.liftSpeed

    def getLiftDirection(self):
        return SkiLift.liftDirection

    def ride(self):
        if self.slow and self.nbCycles % 3 != 0:  # Adjust speed difference here
            return
        # out of track at right
        if self.getX() > 700:
            self.angle = 2 + (int)(2 * random.random())
        # out of track at left
        elif self.getX() < 330:
            self.angle = -2 -(int)(2 * random.random())
        elif self.angle2 > 70:
            self.angle = -2 -(int)(2 * random.random())
        elif self.angle2 < -70:
            self.angle = 2 + (int)(2 * random.random())
        self.angle2 = self.angle2 + self.angle
#    infoBoard.incSkiingDistance(slow);
        self.setDirection(self.angle2 + 90)
        self.move()

    def act(self):
        skiLift = self.skiResort.skiLift
        self.infoBoard.incTotalTime()
        if self.getState() == "onTrack":
            if not self.trackCountReported:
                self.infoBoard.incTrackCount(self.slow)
                self.trackCountReported = True
            self.infoBoard.incSkiingTime(self.slow)
            self.ride()
            if self.getY() > 575:
                self.setState("inQueue")
                self.trackCountReported = False
                skiLift.put(self)
    
        elif self.getState() == "onLift":
            self.infoBoard.incLiftTime(self.slow)
            self.useLift()
            if self.getY() < 50:
                self.setState("onTop")
                self.setDirection(-3)
                self.setHorzMirror(True)
                if self.isSlow():
                    self.show(2)
                else:
                    self.show(3)

        elif self.getState() == "onTop":        
            self.infoBoard.incLiftTime(self.slow)
            if self.getX() > 350: # start ride
                self.angle2 = int(120 * random.random() - 60)
                if self.angle2 < 0:
                    self.angle = 2
                else:
                    self.angle = -2
                self.setState("onTrack")
                self.setHorzMirror(False)
                if self.isSlow():
                    self.show(0)
                else:
                    self.show(1)
            else: # move to right
                self.setPosition(self.posX + SkiLift.liftDirectionTop[0] * SkiLift.liftSpeed, 
                                 self.posY + SkiLift.liftDirectionTop[1] * SkiLift.liftSpeed)
                self.setLocation(self.posToLoc())
 
        elif self.getState() == "inQueue":
            self.infoBoard.incWaitingTime(self.slow)

    def useLift(self):
        self.setPosition(self.posX + SkiLift.liftDirection[0] * SkiLift.liftSpeed, 
                         self.posY + SkiLift.liftDirection[1] * SkiLift.liftSpeed)
        self.setLocation(self.posToLoc())

    def setState(self, state):
        self.state = state

    def getState(self):
        return self.state
    
    def setPosition(self, x, y):
        # float location
        self.posX = x
        self.posY = y
        
    def posToLoc(self):
        return Location(int(self.posX), int(self.posY))

    def getId(self):
        return self.id

    def isSlow(self):
        return self.slow
